# fastcldf

Quickly create CLDF datasets.

[![Tests](https://img.shields.io/github/actions/workflow/status/fmatter/fastcldf/python-app.yml?label=tests)](https://github.com/fmatter/fastcldf/actions/workflows/python-app.yml)
[![Versions](https://img.shields.io/pypi/pyversions/fastcldf)](https://www.python.org/)
[![PyPI](https://img.shields.io/pypi/v/fastcldf.svg)](https://pypi.org/project/fastcldf)
[![License](https://img.shields.io/github/license/fmatter/fastcldf)](https://www.apache.org/licenses/LICENSE-2.0)
